CacheMisconfigurationException class

Failure occurring when the structure of data does not match that of the request operation document.

This is checked by leveraging normalize

Inheritance
Implemented types
Annotations

Constructors

CacheMisconfigurationException(PartialDataException originalException, StackTrace originalStackTrace, {Request? request, FragmentRequest? fragmentRequest, required Map<String, dynamic> data})
const

Properties

data → Map<String, dynamic>
final
fragmentRequest → FragmentRequest?
final
hashCode → int
The hash code for this object.
no setterinherited
originalException → PartialDataException
The original exception causing this exception
final
originalStackTrace → StackTrace
final
request → Request?
final
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() → String
A string representation of this object.
override

Operators

operator ==(Object other) → bool
The equality operator.
inherited