CacheMissException class

A failure to find a response from the cache.

Can occur when cacheOnly=true, or when the request was just written to the cache with expectedData

Inheritance
Annotations

Constructors

CacheMissException(String message, Request request, {Map<String, dynamic>? expectedData})

Properties

expectedData → Map<String, dynamic>?
The data just written to the cache under request, if any.
final
hashCode → int
The hash code for this object.
no setterinherited
message → String
final
originalException → Object?
The original exception causing this exception
finalinherited
originalStackTrace → StackTrace?
finalinherited
request → Request
final
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() → String
A string representation of this object.
override

Operators

operator ==(Object other) → bool
The equality operator.
inherited