CacheRereadPolicy enum

CacheRereadPolicy determines whether and how cache data will be merged into the final QueryResult data before it is returned.

It does not effect optimisticResults added to QueryOptions, etc.

  • mergeOptimistic: Merge relevant optimistic data from the cache before returning.
  • ignoreOptimistic: Ignore optimistic data, but still allow for non-optimistic cache rebroadcasts if applicable.
  • ignoreAll: Ignore all cache data besides the result, and never rebroadcast the result, even if the underlying cache data changes.

The default cacheRereadPolicy for each method are:

Inheritance
Available extensions

Values

mergeOptimistic → const CacheRereadPolicy

Merge relevant optimistic data from the cache before returning.

ignoreOptimisitic → const CacheRereadPolicy

Ignore optimistic data, but still allow for non-optimistic cache rebroadcasts if applicable.

ignoreAll → const CacheRereadPolicy

Ignore all cache data besides the result, and never rebroadcast the result, even if the underlying cache data changes.

Properties

hashCode → int
The hash code for this object.
no setterinherited
index → int
A numeric identifier for the enumerated value.
no setterinherited
name → String

Available on Enum, provided by the EnumName extension

The name of the enum value.
no setter
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited

Constants

values → const List<CacheRereadPolicy>
A constant List of the values in this enum, in order of their declaration.