ConnectionError class

The server will send this error message after receiving the init command from the client if the init was not successful.

Inheritance

Constructors

ConnectionError(dynamic payload)

Properties

hashCode → int
The hash code for this object.
no setterinherited
payload → dynamic
final
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited
type → String
finalinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson() → Map<String, dynamic>
override
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited