FlutterGraphqlClient class

Constructors

FlutterGraphqlClient.init({required String graphQlEndPoint, String? webSocketUrl, String? accessToken, Token? token, String? tokenExpiryErrorCode, dynamic onTokenRefreshFailed(GraphQLService service)?, required Future<Token?> refreshTokenHandler(String refreshToken, GraphQLService service)})
factory

Properties

graphQlEndPoint → String
final
graphQLService ↔ GraphQLService?
getter/setter pair
hashCode → int
The hash code for this object.
no setterinherited
onTokenRefreshFailed → dynamic Function(GraphQLService service)?
final
refreshTokenHandler → Future<Token?> Function(String refreshToken, GraphQLService service)
final
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited
token ↔ Token?
getter/setter pair
tokenExpiryErrorCode ↔ String?
getter/setter pair
webSocketUrl ↔ String?
getter/setter pair

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() → String
A string representation of this object.
inherited
updateAccessToken(String token) → void
updateRefreshToken(String token) → void
updateWebSocketUrl(String webSocketUrl) → void

Operators

operator ==(Object other) → bool
The equality operator.
inherited

Static Properties

instance → FlutterGraphqlClient
no setter