Fragment class

A fragment in a document, optionally defined by fragmentName

Annotations

Constructors

Fragment({required DocumentNode document, String? fragmentName})
const

Properties

document → DocumentNode
Document containing at least one FragmentDefinitionNode
final
fragmentName → String?
Name of the fragment definition
final
hashCode → int
The hash code for this object.
no setteroverride
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited

Methods

asRequest({required Map<String, dynamic> idFields, Map<String, dynamic> variables = const <String, dynamic>{}}) → FragmentRequest
helper for building a FragmentRequest
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() → String
A string representation of this object.
override

Operators

operator ==(Object o) → bool
The equality operator.
override