GraphQLWebSocketChannel class

Inheritance
  • Object
  • StreamChannelMixin
  • GraphQLWebSocketChannel
Implemented types
  • StreamChannelMixin
Available extensions

Constructors

GraphQLWebSocketChannel(WebSocketChannel _webSocket)

Properties

closeCode → int?
The close code set when the WebSocket connection is closed.
no setter
closeReason → String?
The close reason set when the WebSocket connection is closed.
no setter
hashCode → int
The hash code for this object.
no setterinherited
messages → Stream<GraphQLSocketMessage>
Stream of messages from the endpoint parsed as GraphQLSocketMessages
no setter
protocol → String?
The subprotocol selected by the server.
no setter
ready → Future<void>
A future that will complete when the WebSocket connection has been established.
no setter
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited
sink → WebSocketSink
The sink for sending values to the other endpoint.
no setteroverride
stream ↔ Stream
The single-subscription stream that emits values from the other endpoint.
getter/setter pairoverride-getter

Methods

cast<S>() → StreamChannel<S>
Returns a copy of this with the generic type coerced to S.
inherited
changeSink(StreamSink change(StreamSink)) → StreamChannel
Returns a copy of this with sink replaced by change's return value.
inherited
changeStream(Stream change(Stream)) → StreamChannel
Returns a copy of this with stream replaced by change's return value.
inherited
forGraphQL() → GraphQLWebSocketChannel

Available on WebSocketChannel, provided by the GraphQLGetter extension

Returns a wrapper that has safety and convenience features for graphql
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
pipe(StreamChannel other) → void
Connects this to other, so that any values emitted by either are sent directly to the other.
inherited
toString() → String
A string representation of this object.
inherited
transform<S>(StreamChannelTransformer<S, dynamic> transformer) → StreamChannel<S>
Transforms this using transformer.
inherited
transformSink(StreamSinkTransformer transformer) → StreamChannel
Transforms only the sink component of this using transformer.
inherited
transformStream(StreamTransformer transformer) → StreamChannel
Transforms only the stream component of this using transformer.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited