HttpLinkParserException class

Exception occurring when parsing fails.

Inheritance
Annotations

Constructors

HttpLinkParserException({required Object? originalException, required StackTrace? originalStackTrace, required Response response})
const

Properties

hashCode → int
The hash code for this object.
no setterinherited
originalException → Object?
The original exception causing this exception
finalinherited
originalStackTrace → StackTrace?
finalinherited
response → Response
Response which caused the exception
final
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited