Link class abstract

DocumentNode-based GraphQL execution interface

Implementers

Constructors

Link()
Create a Link
const
Link.concat(Link first, Link second)
Create a Link by chaining two links
factory
Link.from(List<Link> links)
Create a Link by chaining multiple links
factory
Link.function(LinkFunction function)
Create a Link from a LinkFunction
factory
Link.route(LinkRouter route)
Creates a Link which routes Request to whichever link is returned from the route function
factory
Link.split(bool test(Request request), Link left, [Link right = const PassthroughLink()])
Create a Link which routes to the left link if test returns true. Otherwise it routes to the right link, which defaults to passthrough.
factory

Properties

hashCode → int
The hash code for this object.
no setterinherited
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited

Methods

concat(Link next) → Link
Adds next after this link
dispose() → Future<void>
Can be called to clean up resources
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
request(Request request, [NextLink? forward]) → Stream<Response>
A function called when a request reaches this Link
route(LinkRouter route) → Link
Route requests after this link
split(bool test(Request request), Link left, [Link right = const PassthroughLink()]) → Link
Split requests after this link
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited