LinkException class abstract

A base class for exceptions thrown by links

Implemented types
Annotations

Constructors

LinkException(Object? originalException, StackTrace? originalStackTrace)
const

Properties

hashCode → int
The hash code for this object.
no setterinherited
originalException → Object?
The original exception causing this exception
final
originalStackTrace → StackTrace?
final
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() → String
A string representation of this object.
override

Operators

operator ==(Object other) → bool
The equality operator.
inherited