MismatchedDataStructureException class

A failure due to a data structure mismatch between the data and the expected structure based on the request operation document.

If validateStructure passes, then the mismatch must be due to a cache misconfiguration, CacheMisconfigurationException.

Inheritance

Constructors

MismatchedDataStructureException(PartialDataException originalException, StackTrace originalStackTrace, {Request? request, required Map<String, dynamic>? data})
const

Properties

data → Map<String, dynamic>?
final
hashCode → int
The hash code for this object.
no setterinherited
originalException → PartialDataException
The original exception causing this exception
final
originalStackTrace → StackTrace
final
request → Request?
final
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() → String
A string representation of this object.
override

Operators

operator ==(Object other) → bool
The equality operator.
inherited