MultiSourceResult<TParsed> class

Constructors

MultiSourceResult({required BaseOptions<TParsed> options, QueryResult<TParsed>? eagerResult, FutureOr<QueryResult<TParsed>>? networkResult})

Properties

eagerResult ↔ QueryResult<TParsed>
getter/setter pair
hashCode → int
The hash code for this object.
no setterinherited
networkResult ↔ FutureOr<QueryResult<TParsed>>?
getter/setter pair
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited