MutationCallbackHandler<TParsed> class

Handles execution of mutation update, onCompleted, and onError callbacks

Constructors

MutationCallbackHandler({required MutationOptions<TParsed> options, required GraphQLCache cache, required String queryId})

Properties

cache → GraphQLCache
final
callbacks → Iterable<OnData<TParsed>>
no setter
hashCode → int
The hash code for this object.
no setterinherited
onCompleted → OnData<TParsed>?
no setter
onError → OnData<TParsed>?
no setter
options → MutationOptions<TParsed>
final
queryId → String
final
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited
update → OnData<TParsed>?
no setter

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited