Operation class

An operation in a document, optionally defined by operationName

Available extensions
Annotations

Constructors

Operation({required DocumentNode document, String? operationName})
const

Properties

document → DocumentNode
Document containing at least one OperationDefinitionNode
final
hashCode → int
The hash code for this object.
no setteroverride
operationName → String?
Name of the executable definition
final
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited

Methods

asRequest({Map<String, dynamic> variables = const <String, dynamic>{}}) → Request

Available on Operation, provided by the OperationRequestHelper extension

helper for building a Request
getOperationType() → OperationType?

Available on Operation, provided by the OperationTypeExtension extension

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() → String
A string representation of this object.
override

Operators

operator ==(Object o) → bool
The equality operator.
override