Policies class

Container for supplying fetch, error, and cacheReread policies.

If any are null, the appropriate policy will be selected from DefaultPolicies

Annotations

Constructors

Policies({FetchPolicy? fetch, ErrorPolicy? error, CacheRereadPolicy? cacheReread})
Policies.safe(FetchPolicy fetch, ErrorPolicy error, CacheRereadPolicy cacheReread)

Properties

allowsRebroadcasting → bool
Returns false if either fetch or cacheReread policies have disabled rebroadcast.
no setter
cacheReread → CacheRereadPolicy?
Specifies the CacheRereadPolicy to be used.
final
error → ErrorPolicy?
Specifies the ErrorPolicy to be used.
final
fetch → FetchPolicy?
Specifies the FetchPolicy to be used.
final
hashCode → int
The hash code for this object.
no setteroverride
mergeOptimisticData → bool
no setter
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited

Methods

copyWith({FetchPolicy? fetch, ErrorPolicy? error}) → Policies
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() → String
A string representation of this object.
override
withOverrides([Policies? overrides]) → Policies

Operators

operator ==(Object other) → bool
The equality operator.
override