QueryCallbackHandler<TParsed> class

Handles execution of query callbacks

Constructors

QueryCallbackHandler({required QueryOptions<TParsed> options})

Properties

callbacks → Iterable<OnData<TParsed>>
no setter
hashCode → int
The hash code for this object.
no setterinherited
onCompleted → OnData<TParsed>?
no setter
onError → OnData<TParsed>?
no setter
options → QueryOptions<TParsed>
final
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited