Store class abstract

Raw key-value datastore API leveraged by the Cache

Annotations

Constructors

Store()

Properties

hashCode → int
The hash code for this object.
no setterinherited
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited

Methods

delete(String dataId) → void
Delete the value of the dataId from the store, if preset
get(String dataId) → Map<String, dynamic>?
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
put(String dataId, Map<String, dynamic>? value) → void
Write value into this store under the key dataId
putAll(Map<String, Map<String, dynamic>?> data) → void
put all entries from data into the store
reset() → void
Empty the store
toMap() → Map<String, Map<String, dynamic>?>
Return the entire contents of the cache as Map.
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited