SubscriptionOptions<TParsed extends Object?> class

Annotations

Constructors

SubscriptionOptions({required DocumentNode document, String? operationName, Map<String, dynamic> variables = const {}, FetchPolicy? fetchPolicy, ErrorPolicy? errorPolicy, CacheRereadPolicy? cacheRereadPolicy, Object? optimisticResult, Context? context, ResultParserFn<TParsed>? parserFn, Duration? queryRequestTimeout})

Properties

asRequest → Request
Resolve these options into a request
no setterinherited
cacheRereadPolicy → CacheRereadPolicy?
no setterinherited
context → Context
Context to be passed to link execution chain.
finalinherited
document → DocumentNode
Document containing at least one OperationDefinitionNode
finalinherited
errorPolicy → ErrorPolicy?
no setterinherited
fetchPolicy → FetchPolicy?
no setterinherited
hashCode → int
The hash code for this object.
no setterinherited
isMutation → bool
no setterinherited
isQuery → bool
no setterinherited
isSubscription → bool
no setterinherited
operationName → String?
Name of the executable definition
finalinherited
optimisticResult → Object?
An optimistic result to eagerly add to the operation stream
finalinherited
parserFn → ResultParserFn<TParsed>
finalinherited
policies → Policies
Specifies the Policies to be used during execution.
finalinherited
properties → List<Object?>
no setterinherited
queryRequestTimeout → Duration?
Override default query timeout
finalinherited
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited
type → OperationType
no setterinherited
variables → Map<String, dynamic>
A map going from variable name to variable value, where the variables are used within the GraphQL query.
finalinherited

Methods

copyWithPolicies(Policies policies) → SubscriptionOptions<TParsed>
createResult({Map<String, dynamic>? data, OperationException? exception, Context context = const Context(), required QueryResultSource source}) → QueryResult<TParsed>
inherited
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
properties based deep equality check
inherited