UnknownException class

Exception occurring when an unhandled, non-link exception is thrown during execution

Inheritance
Annotations

Constructors

UnknownException(Object originalException, StackTrace originalStackTrace)
const

Properties

hashCode → int
The hash code for this object.
no setterinherited
message → String
no setter
originalException → Object?
The original exception causing this exception
finalinherited
originalStackTrace → StackTrace?
finalinherited
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() → String
A string representation of this object.
override

Operators

operator ==(Object other) → bool
The equality operator.
inherited