GraphQLService class

Constructors

GraphQLService()

Properties

hashCode → int
The hash code for this object.
no setterinherited
isCancelled → bool
no setter
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited

Methods

cancelAllRequests() → void
initializeClient() → void
mutate(String mutation, {Map<String, dynamic>? variables}) → Future<ResponseModel>
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
query(String queries, {Map<String, dynamic>? variables}) → Future<ResponseModel>
resumeRequests() → void
subscribe(String subscription, {Map<String, dynamic>? variables}) → Stream<QueryResult<Object?>>
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited