Token class

Constructors

Token({required String accessToken, required String refreshToken})

Properties

accessToken ↔ String
getter/setter pair
hashCode → int
The hash code for this object.
no setterinherited
refreshToken ↔ String
getter/setter pair
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited

Methods

copyWith({String? accessToken, String? refreshToken}) → Token
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited